translate.storage.oo.oounit

Package translate :: Package storage :: Module oo :: Class oounit |
[hide private]
[frames] | no frames]

# Class oounit

source code

this represents a number of translations of a resource

Instance Methods | [hide private]
__init__(self) construct the oounit | source code
addline(self, line) add a line to the oounit | source code
__str__(self) convert to a string. | source code
getoutput(self) return the lines in tab-delimited form | source code

Method Details | [hide private]

### __str__(self) (Informal representation operator) | source code
convert to a string. double check that unicode is handled